/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */

package org.enhydra.barracuda.discRack.data.disc;

import java.io.*;
import java.sql.*;
import java.math.*;
import com.lutris.appserver.server.*;
import com.lutris.appserver.server.sql.*;
import com.lutris.dods.builder.generator.query.*;


/**
 * Interface implemented by DiscDO.
 * Interface could also be implemented by a (hand-written) Business Layer class
 * which uses DiscDO.
 *
 * @version $Revision: 1.2 $
 * @author  ChristianC
 * @since   org.enhydra.barracuda.discRack
 */
public interface DiscDOI {


////////////////////////// data member Title


   /**
    * Get title of the Disc
    *
    * @return title of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getTitle ()
   throws DataObjectException;


   
   /**
    * Set title of the Disc
    *
    * @param title of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setTitle ( String title )
   throws DataObjectException;
   


////////////////////////// data member Artist


   /**
    * Get artist of the Disc
    *
    * @return artist of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getArtist ()
   throws DataObjectException;


   
   /**
    * Set artist of the Disc
    *
    * @param artist of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setArtist ( String artist )
   throws DataObjectException;
   


////////////////////////// data member Genre


   /**
    * Get genre of the Disc
    *
    * @return genre of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getGenre ()
   throws DataObjectException;


   
   /**
    * Set genre of the Disc
    *
    * @param genre of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setGenre ( String genre )
   throws DataObjectException;
   


////////////////////////// data member Owner


   /**
    * Get owner of the Disc
    *
    * @return owner of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public org.enhydra.barracuda.discRack.data.person.PersonDO getOwner ()
   throws DataObjectException;


   
   /**
    * Set owner of the Disc
    *
    * @param owner of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setOwner ( org.enhydra.barracuda.discRack.data.person.PersonDO owner )
   throws DataObjectException;
   


////////////////////////// data member IsLiked


   /**
    * Get isLiked of the Disc
    *
    * @return isLiked of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public boolean getIsLiked ()
   throws DataObjectException;


   
   /**
    * Set isLiked of the Disc
    *
    * @param isLiked of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setIsLiked ( boolean isLiked )
   throws DataObjectException;
   


  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;


  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the save() method of another DO
   * which references this DO.
   * 
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the commit() method of another DO
   * which references this DO.
   * 
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   * The transaction is likely provided by the delete() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;



}
